<?php
/**
* Enqueue scripts and styles
*
* @package GridFeel WordPress Theme
* @copyright Copyright (C) 2023 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridfeel_scripts() {
    wp_enqueue_style('gridfeel-maincss', get_stylesheet_uri(), array(), NULL);
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), NULL );
    wp_enqueue_style('gridfeel-webfont', '//fonts.googleapis.com/css?family=Roboto+Slab:400,700|Oswald:400,700|Frank+Ruhl+Libre:400,700|Bree+Serif&amp;display=swap', array(), NULL);

    $gridfeel_primary_menu_active = FALSE;
    if ( gridfeel_is_primary_menu_active() ) {
        $gridfeel_primary_menu_active = TRUE;
    }
    $gridfeel_secondary_menu_active = FALSE;
    if ( gridfeel_is_secondary_menu_active() ) {
        $gridfeel_secondary_menu_active = TRUE;
    }

    $gridfeel_sticky_menu_active = FALSE;
    $gridfeel_sticky_mobile_menu_active = FALSE;
    if ( gridfeel_is_sticky_menu_active() ) {
        $gridfeel_sticky_menu_active = TRUE;
    }
    if ( gridfeel_is_sticky_mobile_menu_active() ) {
        $gridfeel_sticky_mobile_menu_active = TRUE;
    }

    $gridfeel_fitvids_active = FALSE;
    if ( gridfeel_is_fitvids_active() ) {
        $gridfeel_fitvids_active = TRUE;
    }
    if ( $gridfeel_fitvids_active ) {
        wp_enqueue_script('fitvids', get_template_directory_uri() .'/assets/js/jquery.fitvids.min.js', array( 'jquery' ), NULL, true);
    }

    $gridfeel_backtotop_active = FALSE;
    if ( gridfeel_is_backtotop_active() ) {
        $gridfeel_backtotop_active = TRUE;
    }

    $gridfeel_sticky_sidebar_active = TRUE;
    if ( is_page_template( array( 'template-full-width-page.php', 'template-full-width-page-sidebar.php', 'template-full-width-post.php', 'template-full-width-post-sidebar.php' ) ) ) {
       $gridfeel_sticky_sidebar_active = FALSE;
    }
    if ( is_404() ) {
        $gridfeel_sticky_sidebar_active = FALSE;
    }
    if ( $gridfeel_sticky_sidebar_active ) {
        wp_enqueue_script('ResizeSensor', get_template_directory_uri() .'/assets/js/ResizeSensor.min.js', array( 'jquery' ), NULL, true);
        wp_enqueue_script('theia-sticky-sidebar', get_template_directory_uri() .'/assets/js/theia-sticky-sidebar.min.js', array( 'jquery' ), NULL, true);
    }

    wp_enqueue_script('gridfeel-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), NULL, true );
    wp_enqueue_script('gridfeel-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), NULL, true );
    wp_enqueue_script('gridfeel-customjs', get_template_directory_uri() .'/assets/js/custom.js', array( 'jquery', 'imagesloaded' ), NULL, true);
    wp_localize_script( 'gridfeel-customjs', 'gridfeel_ajax_object',
        array(
            'ajaxurl' => esc_url_raw( admin_url( 'admin-ajax.php' ) ),
            'primary_menu_active' => $gridfeel_primary_menu_active,
            'secondary_menu_active' => $gridfeel_secondary_menu_active,
            'sticky_menu_active' => $gridfeel_sticky_menu_active,
            'sticky_mobile_menu_active' => $gridfeel_sticky_mobile_menu_active,
            'sticky_sidebar_active' => $gridfeel_sticky_sidebar_active,
            'fitvids_active' => $gridfeel_fitvids_active,
            'backtotop_active' => $gridfeel_backtotop_active,
        )
    );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    wp_enqueue_script('gridfeel-html5shiv-js', get_template_directory_uri() .'/assets/js/html5shiv.js', array('jquery'), NULL, true);

    wp_localize_script('gridfeel-html5shiv-js','gridfeel_custom_script_vars',array(
        'elements_name' => esc_html__('abbr article aside audio bdi canvas data datalist details dialog figcaption figure footer header hgroup main mark meter nav output picture progress section summary template time video', 'gridfeel'),
    ));
}
add_action( 'wp_enqueue_scripts', 'gridfeel_scripts' );

/**
 * Enqueue IE compatible scripts and styles.
 */
function gridfeel_ie_scripts() {
    wp_enqueue_script( 'respond', get_template_directory_uri(). '/assets/js/respond.min.js', array(), NULL, false );
    wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'gridfeel_ie_scripts' );

/**
 * Enqueue styles for the block-based editor.
 */
function gridfeel_block_editor_styles() {
    wp_enqueue_style( 'gridfeel-block-editor-style', get_template_directory_uri() . '/assets/css/editor-blocks.css', array(), NULL );
}
add_action( 'enqueue_block_editor_assets', 'gridfeel_block_editor_styles' );

/**
 * Enqueue customizer styles.
 */
function gridfeel_enqueue_customizer_styles() {
    wp_enqueue_style( 'gridfeel-customizer-styles', get_template_directory_uri() . '/inc/admin/css/customizer-style.css', array(), NULL );
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), NULL );
}
add_action( 'customize_controls_enqueue_scripts', 'gridfeel_enqueue_customizer_styles' );